docs.rs failed to build odra-modules-2.8.2
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
odra-modules-2.9.1
Odra Modules
Collection of reusable Odra modules.
erc20.rs- ERC20 token, adjusted to Odra.wrapped_native.rs- ERC20-based wrapped native token.erc721.rs- ERC721 token, adjusted to Odra.erc1155.rs- ERC1155 token, adjusted to Odra.