pub struct AccessControl { /* private fields */ }Expand description
This contract module enables the implementation of role-based access control mechanisms for children modules.
Roles are identified by their 32-bytes identifier, which should be unique and exposed in the external API.
Roles can be used to represent a set of permissions, and the hasRole function is used to restrict access to a function call.
Roles can be granted and revoked dynamically using the grant_role() and
revoke_role() functions,
respectively. Each role has an associated admin role, and only accounts that have the role’s admin role
can call grant_role and revoke_role.
By default, the admin role for all roles is DEFAULT_ADMIN_ROLE, which means that only accounts with
this role can grant or revoke other roles.
More complex role relationships can be established using the set_admin_role() function.
Implementations
Sourceimpl AccessControl
impl AccessControl
Sourcepub fn has_role(&self, role: &Role, address: &Address) -> bool
pub fn has_role(&self, role: &Role, address: &Address) -> bool
Returns true if account has been granted role.
Sourcepub fn get_role_admin(&self, role: &Role) -> Role
pub fn get_role_admin(&self, role: &Role) -> Role
Returns the admin role that controls role.
The admin role may be changed using set_admin_role().
Sourcepub fn grant_role(&mut self, role: &Role, address: &Address)
pub fn grant_role(&mut self, role: &Role, address: &Address)
Grants role to address.
If the role has been already granted - nothing happens,
otherwise RoleGranted event is emitted.
The caller must have role’s admin role.
Sourcepub fn revoke_role(&mut self, role: &Role, address: &Address)
pub fn revoke_role(&mut self, role: &Role, address: &Address)
Grants role to address.
If the role has been already revoked - nothing happens,
otherwise RoleRevoked event is emitted.
The caller must have role’s admin role.
Sourcepub fn renounce_role(&mut self, role: &Role, address: &Address)
pub fn renounce_role(&mut self, role: &Role, address: &Address)
The function is used to remove a role from the account that initiated the call.
One common way of managing roles is by using grant_role()
and revoke_role().
The purpose of revokeRole is to provide a mechanism for revoking privileges from an account
in case it gets compromised.
If the account had previously been granted the role, the function will trigger a RoleRevoked event.
Note that only address is authorized to call this function.
Sourceimpl AccessControl
impl AccessControl
Sourcepub fn check_role(&self, role: &Role, address: &Address)
pub fn check_role(&self, role: &Role, address: &Address)
Ensures address has role. If not, reverts with Error::MissingRole.
Sourcepub fn set_admin_role(&mut self, role: &Role, admin_role: &Role)
pub fn set_admin_role(&mut self, role: &Role, admin_role: &Role)
Sets admin_role as role’s admin role.
Emits a RoleAdminChanged event.
Sourcepub fn unchecked_grant_role(&mut self, role: &Role, address: &Address)
pub fn unchecked_grant_role(&mut self, role: &Role, address: &Address)
Grants role to address.
Internal function without access restriction. This function should be used to setup the initial access control.
May emit a RoleGranted event.
Sourcepub fn unchecked_revoke_role(&mut self, role: &Role, address: &Address)
pub fn unchecked_revoke_role(&mut self, role: &Role, address: &Address)
Revokes role from address.
Internal function without access restriction. This function should be used to setup the initial access control.
May emit a RoleRevoked event.